YARP 2.3.8 (2011-07-25)                                                {#v2_3_8}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.7...v2.3.8`):

```
    15	Duarte Aragao <daragao@gmail.com>
    14	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     2	Lorenzo Natale <lorenzo.natale@iit.it>
     1	Marco Randazzo <marco.randazzo@iit.it>
     1	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
```
